      SUBROUTINE LISB(A, N, NUD, N1, B, EPS, DR, Z, IER)
************************************************************************
*  SIMULTANEOUS LINEAR EQUATIONS WITH REAL SYMMETRIC POSITIVE DEFINITE *
*      BAND MATRIX BY CHOLESKY METHOD.                                 *
*  PARAMETERS                                                          *
*    (1) A : 2-DIM. ARRAY CONTAINING THE MATRIX.                       *
*    (2) N : ORDER OF THE MATRIX.                                      *
*    (3) NUD : SIZE OF BAND'S HALF WIDTH.                              *
*    (4) N1 : ROW SIZE OF THE ARRAY A IN THE 'DIMENSION' STATEMENT.    *
*    (5) B : 1-DIM. ARRAY CONTAINING THE RIGHT HAND SIDE VECTOR.       *
*    (6) EPS : PARAMETER TO CHECK SINGURARITY OFF THE MATRIX           *
*              STANDARD VALUE = 1.0D-14                                *
*    (7) DR : 1-DIM. WORKING ARRAY.                                    *
*    (8) Z : 1-DIM. WORKING ARRAY.                                     *
*    (9) IER : ERROR CODE.                                             *
*  COPY RIGHT   T. OGUNI   JULY 30 1989   VERSION 1.0                  *
************************************************************************  
      INCLUDE 'para.inc'      
c       IMPLICIT REAL*8(A-H,O-Z)
       DIMENSION A(N1,N), B(N), DR(N), Z(N)
C  CHECK THE INPUT DATA
      IER = 0
      EPS1 = 1.0D-14
      M = NUD + 1
      IF ((N .LE. 0) .OR. (NUD .LE. 0 ) .OR. (N1 .LT. M)) THEN
       IER = 2
       WRITE(*,*) '(SUBR. LISB) INVALID ARGUMENT. ', N, NUD, N1
       RETURN
      ENDIF
      IF (EPS .LE. 0.0) EPS = EPS1
C  MODIFIED CHOLESKY DECOMPOSITION
      J = 1
      IF (DABS(A(M,1)) .LE. EPS) THEN
       IER = 1
       WRITE(*,*) '(SUBR. LISB) SINGULAR AT STEP # ', J
       RETURN
      ENDIF
      DR(1) = 1.0D0 / A(M,1)
      XX = A(M-1,2)
      A(M-1,2) = A(M-1,2) * DR(1)
      S = A(M,2) - XX * A(M-1,2)
      J = 2
      IF (DABS(S) .LE. EPS) THEN
       IER = 1
       WRITE(*,*) '(SUBR. LISB) SINGULAR AT STEP # ', J
       RETURN
      ENDIF
      DR(2) = 1.0D0 / S
      IF (M .LT. 3) THEN
       DO 5 J=3,N
        XX = A(1,J)
        A(1,J) = XX * DR(J-1)
        S = A(2,J) - XX * A(1,J)
        IF (DABS(S) .LE. EPS) THEN
         IER = 1
         WRITE(*,*) ' (SUBR. LISB) SINGULAR AT STEP # ', J
         RETURN
        ENDIF
        DR(J) = 1.0D0 / S
    5  CONTINUE
      ELSE
       DO 30 J=3,N
        K1 = 1
        IF (J .GE. M) K1 = J - M + 1
        MJ = M - J
        DO 20 I=K1+1,J-1
         SUM = 0.0D0
         DO 10 K=K1,I-1
   10     SUM = SUM + A(M-I+K,I) * A(MJ+K,J)
         A(MJ+I,J) = A(MJ+I,J) - SUM
   20   CONTINUE
        SUM = 0.0D0
        DO 25 I=K1,J-1
         XX = A(MJ+I,J)
         AU = XX * DR(I)
         SUM = SUM + XX *AU
         A(MJ+I,J) = AU
   25   CONTINUE
        T = A(M,J) - SUM
        IF (DABS(T) .LE. EPS) THEN
         IER = 1
         WRITE(*,*) ' (SUBR. LISB) SINGULAR AT STEP # ', J
         RETURN
        ENDIF
        DR(J) = 1.0D0 / T
   30  CONTINUE
      ENDIF
c
c      CALL SBSUB(A,N,NUD,N1,B,DR,Z)
c
      RETURN
      END
